You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by da...@apache.org on 2022/09/07 01:48:34 UTC

[beam] 01/01: Fix example registration input arity

This is an automated email from the ASF dual-hosted git repository.

damccorm pushed a commit to branch users/damccorm/example
in repository https://gitbox.apache.org/repos/asf/beam.git

commit 7656a63774ebac75906dbee8ecb9b5f62454db0a
Author: Danny McCormick <da...@google.com>
AuthorDate: Tue Sep 6 21:48:26 2022 -0400

    Fix example registration input arity
---
 sdks/go/pkg/beam/register/example_register_test.go | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sdks/go/pkg/beam/register/example_register_test.go b/sdks/go/pkg/beam/register/example_register_test.go
index 0b5de858183..19dadc8ab60 100644
--- a/sdks/go/pkg/beam/register/example_register_test.go
+++ b/sdks/go/pkg/beam/register/example_register_test.go
@@ -65,8 +65,8 @@ func (fn *myDoFn2) ProcessElement(word string, iter func(**Foo, *beam.EventTime)
 	return mtime.Now(), word, len(word)
 }
 
-func ExampleDoFn2x1() {
-	// Since myDoFn's ProcessElement call has 2 inputs and 1 output, call DoFn2x1.
+func ExampleDoFn3x1() {
+	// Since myDoFn's ProcessElement call has 3 inputs and 1 output, call DoFn3x1.
 	// Since the inputs to ProcessElement are (string, func(int)), and the output
 	// is int, we pass those parameter types to the function.
 	register.DoFn3x1[string, func(*string) bool, func(int), int](&myDoFn{})